# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.114
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.bulk_invited_organisation_users import BulkInvitedOrganisationUsers  # noqa: E501

class TestBulkInvitedOrganisationUsers(unittest.TestCase):
    """BulkInvitedOrganisationUsers unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkInvitedOrganisationUsers:
        """Test BulkInvitedOrganisationUsers
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkInvitedOrganisationUsers`
        """
        model = BulkInvitedOrganisationUsers()  # noqa: E501
        if include_optional:
            return BulkInvitedOrganisationUsers(
                total_count = 0
            )
        else:
            return BulkInvitedOrganisationUsers(
                total_count = 0,
        )
        """

    def testBulkInvitedOrganisationUsers(self):
        """Test BulkInvitedOrganisationUsers"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.114
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr

class Interface(BaseModel):
    """
    Interface
    """
    id: StrictStr = Field(..., description="Internal ID of an \"Interface\" (e.g `NESO`, `RTE`, etc)")
    display_name: StrictStr = Field(..., alias="displayName")
    __properties = ["id", "displayName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Interface:
        """Create an instance of Interface from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Interface:
        """Create an instance of Interface from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Interface.parse_obj(obj)

        _obj = Interface.parse_obj({
            "id": obj.get("id"),
            "display_name": obj.get("displayName")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.114
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class DefaultNominationDeclarationType(str, Enum):
    """
    DefaultNominationDeclarationType
    """

    """
    allowed enum values
    """
    PERCENT_100 = 'PERCENT_100'
    VALUE = 'VALUE'

    @classmethod
    def from_json(cls, json_str: str) -> DefaultNominationDeclarationType:
        """Create an instance of DefaultNominationDeclarationType from a JSON string"""
        return DefaultNominationDeclarationType(json.loads(json_str))


